// {{{ copyright

/********************************************************************
 *
 * $Id: CommandHandler.java,v 1.3 2000/06/06 17:00:02 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.command;

/**
 * This is the interface through wich {@link Command Commands}
 * that do not implement the {@link Invokable Invokable} interface
 * get executed.
 *
 * CommandHandlers may be registered with a {@link CommandDistributor
 * CommandDistributor} who will pass Commands to the handler's {@link
 * #handleCommand handleCommand} method.
 *
 * If a CommandHandler does handle a command it must call {@link
 * Command#setHandled setHandled} on the command.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.3 $
 */
public interface CommandHandler
{
    /**
     * (Possibly) handle a command. If the command gets handled, its
     * setHandled method should be called.
     *
     * @param   command The Command to handle.
     *
     * @throws  CommandException        If something specific to the
     *          execution of the command goes wrong.
     *
     * @see     Command#setHandled
     */
    public Object handleCommand(Command command)
         throws CommandException;
}
