// {{{ copyright

/********************************************************************
 *
 * $Id: RegistrationHelper.jpp,v 1.2 2000/06/06 16:41:25 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 2000 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.config;

// {{{ imports


import java.util.Set;
import java.util.HashSet;


// }}}

/**
 * Helper class for Configurables that care about the Configurations they
 * are registered with.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.2 $
 */
public class RegistrationHelper
{
    // {{{ variables

    /**
     * The Configurations the client is registered with.
     */
    private Set configurations;

    // }}}

    // {{{ constructor

    public RegistrationHelper ()
    {
    }

    // }}}

    // {{{ registrationChanged

    /**
     * Helper for registrationChanged callbacks on the Configurable.
     *
     * @param   config  The affected Configuration.
     * @param   registered True if the Configurable was just registered,
     *                  false if it was unregistered.
     *
     * @return  -1 if the Configurable was just unrigestered from its last
     *          Configuration, 1 if it was registered with its first
     *          Configuration or 0 if neither.
     */
    public synchronized int registrationChanged
        (Configuration config, boolean registered)
    {
        int ret = 0;
        if (registered) {
            if (configurations == null) {
                configurations = new HashSet ();
                ret = 1;
            } else if (configurations.size() == 0) {
                ret = 1;
            }
            configurations.add(config);
        } else {
            if (configurations != null) {
                int size = configurations.size();
                if (configurations.remove(config) && size == 1) {
                    // This was the last member
                    ret = -1;
                }
            }
        }
        return ret;
    }

    // }}}
    // {{{ stateChanged

    /**
     * Notify all Configurations the client is registered with of a state in
     * the client's state.
     *
     * @param   client  The Configurable that changed.
     */
    public void stateChanged(Configurable client)
    {
        Configuration[] configs = null;
        synchronized (this) {
            if (configurations != null) {
                configs = (Configuration[]) configurations.toArray
                    (new Configuration[0]);
            }
        }
        if (configs != null) {
            for (int i = 0; i < configs.length; i++) {
                configs[i].stateChanged(client);
            }
        }
    }

    // }}}
}
