// {{{ copyright

/********************************************************************
 *
 * $Id: EventNames.jpp,v 1.8 2000/06/14 16:51:28 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.gui;

import java.awt.event.*;


import java.util.Map;
import java.util.HashMap;
import java.util.Iterator;


/**
 * This class provides a mapping from the ids of some AwtEvents
 * to their names and vice versa.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.8 $
 */
public abstract class EventNames
{
    /**
     * Map event ids to event names.
     */
    protected static Map names = new HashMap();

    /**
     * Map event names to event ids.
     *
     * @since   0.96.0
     */
    protected static Map ids = new HashMap();

    /**
     * Initialize the name mapping.
     */
    static {

        names.put (new Integer (InputMethodEvent.CARET_POSITION_CHANGED),
                                "CARET_POSITION_CHANGED");
        names.put (new Integer (InputMethodEvent.INPUT_METHOD_TEXT_CHANGED),
                                "INPUT_METHOD_TEXT_CHANGED");

        names.put (new Integer (KeyEvent.KEY_PRESSED), "KEY_PRESSED");
        names.put (new Integer (KeyEvent.KEY_RELEASED), "KEY_RELEASED");
        names.put (new Integer (KeyEvent.KEY_TYPED), "KEY_TYPED");
        names.put (new Integer (MouseEvent.MOUSE_PRESSED), "MOUSE_PRESSED");
        names.put (new Integer (MouseEvent.MOUSE_RELEASED), "MOUSE_RELEASED");
        names.put (new Integer (MouseEvent.MOUSE_CLICKED), "MOUSE_CLICKED");
        names.put (new Integer (MouseEvent.MOUSE_MOVED), "MOUSE_MOVED");
        names.put (new Integer (MouseEvent.MOUSE_DRAGGED), "MOUSE_DRAGGED");
        names.put (new Integer (WindowEvent.WINDOW_OPENED), "WINDOW_OPENED");
        names.put (new Integer (WindowEvent.WINDOW_CLOSING), "WINDOW_CLOSING");
        names.put (new Integer (WindowEvent.WINDOW_CLOSED), "WINDOW_CLOSED");
        names.put (new Integer (WindowEvent.WINDOW_ICONIFIED),
                   "WINDOW_ICONIFIED");
        names.put (new Integer (WindowEvent.WINDOW_DEICONIFIED),
                   "WINDOW_DEICONIFIED");
        names.put (new Integer (WindowEvent.WINDOW_ACTIVATED),
                   "WINDOW_ACTIVATED");
        names.put (new Integer (WindowEvent.WINDOW_DEACTIVATED),
                   "WINDOW_DEACTIVATED");
        names.put (new Integer (WindowEvent.COMPONENT_MOVED),
                   "COMPONENT_MOVED");
        names.put (new Integer (WindowEvent.COMPONENT_RESIZED),
                   "COMPONENT_RESIZED");
        for (Iterator iter = names.keySet().iterator(); iter.hasNext(); ) {
            Integer id = (Integer) iter.next();
            ids.put(names.get(id), id);
        }
    }

    /**
     * Get the name of an event.
     *
     * @param   id      The id of the event.
     *
     * @return  The name of the event.
     */
    public static String getName(int id)
    {
        String ret = (String) names.get(new Integer (id));
        if (ret == null) {
            return "UNKNOWN";
        }
        return ret;
    }

    /**
     * Get the id of an event.
     *
     * @param   name    The name of the event.
     *
     * @return  The id of the event or -1 if unknown.
     *
     * @since   0.96.0
     */
    public static int getId(String name)
    {
        Integer ret = (Integer) ids.get(name);
        if (ret == null) {
            return -1;
        }
        return ret.intValue();
    }

}
