// {{{ copyright

/********************************************************************
 *
 * $Id: TableModelSorter.java,v 1.6 2000/06/06 17:00:03 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.gui;

import javax.swing.table.TableModel;

/**
 * Interface for sorters used by {@link FilteredAndSortedTableModel
 * FilteredAndSortedTableModel}. The compare method will be called with the
 * original {@link javax.swing.table.TableModel TableModel} and two
 * row indices into the model.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */

public interface TableModelSorter
{
    /**
     * Compare two rows of the table.
     *
     * @param   model   The original TableModel.
     * @param   idx1    Index of the first row.
     * @param   idx2    Index of the second row.
     *
     * @return  0 if the rows are equal, -1 if the first row's value is less
     *          than the second row's, 1 if it is greater.
     */
    public int compare(TableModel model, int idx1, int idx2);

    /**
     * Add a TableModelSorterListener to the TableModelSorter.
     *
     * @param   listener        The TableModelSorterListener to add.
     */
    public void addTableModelSorterListener(TableModelSorterListener listener);

    /**
     * Remove a TableModelSorterListener from the TableModelSorter.
     *
     * @param   listener        The TableModelSorterListener to remove.
     */
    public void removeTableModelSorterListener
        (TableModelSorterListener listener);

    /**
     * Tell the TableSorter the column to sort on.
     *
     * @param   column  The column to sort on.
     */
    public void setSortColumn(int column);

    /**
     * Get the column being sorted on.
     *
     * @return  The column being sorted on.
     */
    public int getSortColumn();

    /**
     * Tell the TableSorter whether the sort order is ascending.
     *
     * @param   ascending       True for ascending sort order.
     */
    public void setSortAscending(boolean ascending);

    /**
     * Query whether the rows are sorted in ascending order.
     *
     * @return  True for ascending sort order.
     */
    public boolean isSortAscending();
}
