// {{{ copyright

/********************************************************************
 *
 * $Id: WindowsTableCellRenderer.java,v 1.6 2000/06/06 17:00:03 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.gui;

// {{{ imports

import java.awt.Component;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JTable;
import javax.swing.border.Border;
import javax.swing.table.DefaultTableCellRenderer;

// }}}

/**
 * TableCellRenderer that draws a Windows like focus border. This border is a
 * lot more conspicuous than the default focus border in all look and feels.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */
public class WindowsTableCellRenderer
    extends DefaultTableCellRenderer
{
    // {{{ variables

    /**
     * The default icon for the stipple border.
     */
    private static Icon defaultIcon = new ImageIcon
        (WindowsTableCellRenderer.class.getResource
         ("/de/qfs/lib/resources/icons/stipple.gif"));

    /**
     * The icon used for the border.
     */
    private Icon icon;

    /**
     * Border for focused cells.
     */
    private Border focusBorder;

    /**
     * Empty border for non-focused cells
     */
    private Border emptyBorder = BorderFactory.createEmptyBorder(1, 1, 1, 1);

    // }}}

    // {{{ WindowsTableCellRenderer

    /**
     * Create a enw WindowsTableCellRenderer.
     */
    public WindowsTableCellRenderer ()
    {
        icon = defaultIcon;
        focusBorder = Borders.STIPPLE;
    }

    // }}}

    // {{{ getTableCellRendererComponent

    /**
     * Get the Component used to paint the table cell.
     *
     * @param   table   The table to paint.
     * @param   value   The value of the cell.
     * @param   selected        Whether the cell is selected.
     * @param   focus           Whether the cell has the focus - ignored.
     * @param   row     The cell's row index.
     * @param   column  The cell's column index.
     *
     * @return  A JLabel that will paint the cell with the correct border.
     */
    public Component getTableCellRendererComponent
    (JTable table, Object value, boolean selected, boolean hasFocus,
     int row, int column)
    {
        DefaultTableCellRenderer com = (DefaultTableCellRenderer)
            super.getTableCellRendererComponent(table, value, selected,
                                                hasFocus && icon == null,
                                                row, column);
        if (icon != null) {
            if (hasFocus) {
                com.setBorder(focusBorder);
            } else {
                com.setBorder(emptyBorder);
            }
        }
        return com;
    }

    // }}}
    // {{{ setBorderIcon

    /**
     * Set the icon to use for painting the focus border.
     *
     * @param   icon    The icon for the border.
     */
    public void setBorderIcon(Icon icon)
    {
        this.icon = icon;
        if (icon != null) {
            focusBorder = BorderFactory.createMatteBorder(1, 1, 1, 1, icon);
        }
    }

    // }}}
}
