// {{{ copyright

/********************************************************************
 *
 * $Id: LogClientImplBase.java,v 1.1 2000/07/04 13:43:51 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.logrmi;

// {{{ imports

import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

// }}}

/**
 * If a class wants to implement the {@link LogClient LogClient} interface it
 * should do so by extending this abstract class instead of {@link
 * java.rmi.server.UnicastRemoteObject UnicastRemoteObject}. That way it
 * doesn't have to care about the RMI stubs, since they are part of the
 * de.qfs.lib.logrmi package. Otherwise it will have to make the stubs
 * available itself.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.1 $
 */
public abstract class LogClientImplBase
    extends UnicastRemoteObject
    implements LogClient
{
    // {{{ constructor

    /**
     * Create a new LogClientImplBase.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public LogClientImplBase ()
        throws RemoteException
    {
    }

    // }}}

    // {{{ connect

    /**
     * Tell the LogClient that it should disengage from the registry and
     * connect itself to a LogServer.
     *
     * @param   server  The LogServer to connect to.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public abstract void connect(LogServer server)
        throws RemoteException;

    // }}}
}
