// {{{ copyright

/********************************************************************
 *
 * $Id: LogListener.java,v 1.1 2000/07/04 13:43:51 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.logrmi;

import java.rmi.Remote;
import java.rmi.RemoteException;

import de.qfs.lib.log.LogEntry;

/**
 * A LogListener waits for calls from clients that dump their
 * LogEntries into the LogServer.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.1 $
 */
public interface LogListener extends Remote
{
    /**
     * Accept a log message.
     *
     * @param   entry   The LogEntry that holds the message details.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void log (LogEntry entry)
         throws RemoteException;

    /**
     * Accept many log messages.
     *
     * @param   entries A LogEntry array that holds the message details.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void log (LogEntry[] entries)
         throws RemoteException;

    /**
     * End the connection with the LogListener.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void disconnect ()
         throws RemoteException;

}
