// {{{ copyright

/********************************************************************
 *
 * $Id: LogServer.java,v 1.1 2000/07/04 13:43:51 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.logrmi;

import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * A LogServer is a factory for LogListeners. Clients have to register under
 * their name.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.1 $
 */
public interface LogServer extends Remote
{
    /**
     * Get an Id for a new client. Different clients may connect under the same
     * name, so this identification mechanism is required to differentiate
     * between them.
     *
     * @return  A unique handle identifying the client to the server.
     */
    public int getId(String clientName)
         throws RemoteException;

    /**
     * Get a LogListener for a client.
     *
     * @param   id      The client identifier obtained with {@link #getId
     *                  getId}.
     *
     * @return  The LogListener
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public LogListener getLogListener(int id)
         throws RemoteException;

    /**
     * Get a LogLevelListener for a client.
     *
     * @param   id      The client identifier obtained with {@link #getId
     *                  getId}.
     *
     * @return  The LogLevelListener
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public RemoteLogLevelListener getLogLevelListener(int id)
         throws RemoteException;

    /**
     * Disconnect the client from the server. This should automatically
     * disconnect from any LogListener and LogLevelListener returned by the
     * server from {@link #getLogListener getLogListener} or {@link
     * #getLogLevelListener getLogLevelListener}.
     *
     * @param   id      The client identifier obtained with {@link #getId
     *                  getId}.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void disconnect(int id)
         throws RemoteException;
}
