// {{{ copyright

/********************************************************************
 *
 * $Id: LogServerImplBase.java,v 1.1 2000/07/04 13:43:51 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.logrmi;

// {{{ imports

import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

// }}}

/**
 * If a class wants to implement the {@link LogServer LogServer} interface it
 * should do so by extending this abstract class instead of {@link
 * UnicastRemoteObject UnicastRemoteObject}. That way it doesn't have to care
 * about the RMI stubs, since they are part of the de.qfs.lib.logrmi
 * package. Otherwise it will have to make the stubs available itself.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.1 $
 */
public abstract class LogServerImplBase
    extends UnicastRemoteObject
    implements LogServer
{
    // {{{ constructor

    /**
     * Create a new LogServerImplBase.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public LogServerImplBase ()
         throws RemoteException
    {
    }

    // }}}

    // {{{ getId

    /**
     * Get an Id for a new client. Different clients may connect under the same
     * name, so this identification mechanism is required to differentiate
     * between them.
     *
     * @return  A unique handle identifying the client to the server.
     */
    public abstract int getId(String clientName)
        throws RemoteException;

    // }}}
    // {{{ getLogListener

    /**
     * Get a LogListener for a client.
     *
     * @param   id      The client identifier obtained with {@link #getId
     *                  getId}.
     *
     * @return  The LogListener
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public abstract LogListener getLogListener(int id)
         throws RemoteException;

    // }}}
    // {{{ getLogLevelListener

    /**
     * Get a LogLevelListener for a client.
     *
     * @param   id      The client identifier obtained with {@link #getId
     *                  getId}.
     *
     * @return  The LogLevelListener
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public abstract RemoteLogLevelListener getLogLevelListener(int id)
         throws RemoteException;

    // }}}
    // {{{ disconnect

    /**
     * Disconnect the client from the server.
     *
     * @param   id      The client identifier obtained with {@link #getId
     *                  getId}.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public abstract void disconnect(int id)
         throws RemoteException;

    // }}}
}
