// {{{ copyright

/********************************************************************
 *
 * $Id: RemoteLogLevelListener.java,v 1.1 2000/07/04 13:43:51 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.logrmi;

// {{{ imports

import java.rmi.Remote;
import java.rmi.RemoteException;

import java.util.EventListener;

import de.qfs.lib.log.LogLevelEvent;

// }}}

/**
 * Remote Listener interface for changes in the log levels of an application.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.1 $
 */
public interface RemoteLogLevelListener
    extends EventListener, Remote
{
    /**
     * Notify the listener that a Logger for a formerly unknown class has
     * requested its log level, adding the class to the log level tree.
     *
     * @param   event   The LogLevelEvent holding the details.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void classAdded(LogLevelEvent event)
        throws RemoteException;

    /**
     * Notify the listener that a log level has been changed.
     *
     * @param   event   The LogLevelEvent holding the details.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void levelChanged(LogLevelEvent event)
        throws RemoteException;

    /**
     * Notify the listener that a log level has been unset.
     *
     * @param   event   The LogLevelEvent holding the details.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void levelRemoved(LogLevelEvent event)
        throws RemoteException;

    /**
     * Sets the RemoteLogLevelCallback for the RemoteLogLevelListener.
     *
     * @param   callback        The LogLevelCallback to use to change the
     *                          log levels.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void setLogLevelCallback(RemoteLogLevelCallback callback)
        throws RemoteException;

    /**
     * End the connection with the RemoteLogLevelListener. This should also
     * cause the RemoteLogLevelListener to disconnect from a LogLevelCallback
     * set with {@link #setLogLevelCallback setLogLevelCallback}.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void disconnect()
         throws RemoteException;
}
