// {{{ copyright

/********************************************************************
 *
 * $Id: EditorOption.java,v 1.3 2001/02/04 12:19:50 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 2000 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.option;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * An EditorOption is similar to a StringOption except that its edit Component
 * is a JEditorPane.
 *
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.3 $
 * @since       0.98.0
 */
public class EditorOption
    extends TextOption
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (EditorOption.class);

    // }}}

    // {{{ constructors

    /**
     * Create a new EditorOption.
     */
    public EditorOption()
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "EditorOption()", "");
        }
    }

    /**
     * Create a new EditorOption with a name and a value.
     *
     * @param   name    The name to use.
     * @param   value   The value to use.
     */
    public EditorOption(String name, String value)
    {
        super (name, value);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "EditorOption(String,String)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "name: " + name + ", " +
                       "value: " + value);
        }
    }

    /**
     * Create a new EditorOption with a name and a value and the nullOK flag.
     *
     * @param   name    The name to use.
     * @param   value   The value to use.
     * @param   nullOK  The nullOK flag to use.
     */
    public EditorOption(String name, String value, boolean nullOK)
    {
        super (name, value, nullOK);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "EditorOption(String,String,boolean)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "name: " + name + ", " +
                       "value: " + value + ", " +
                       "nullOK: " + nullOK);
        }
    }

    // }}}

}
