// {{{ copyright

/********************************************************************
 *
 * $Id: FramedOptionGroup.java,v 1.10 2000/12/07 17:53:27 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.option;

// {{{ imports

// import java.awt.Color;

// import javax.swing.BorderFactory;
// import javax.swing.UIManager;
// import javax.swing.border.TitledBorder;

import java.util.Properties;
import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * A FramedOptionGroup extends PlainOptionGroup to display a Frame around its
 * members. <p>
 *
 * See the package documentation for details about the necessary resources.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.10 $
 * @deprecated  Replaced by PlainOptionGroup with the frame property set to
 *              true as of version 0.98.0.
 */
public class FramedOptionGroup
    extends PlainOptionGroup
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private static Logger logger = new Logger (FramedOptionGroup.class);

    // }}}

    // {{{ constructors

    /**
     * No arg constructor for customized OptionGroups.
     */
    protected FramedOptionGroup ()
    {
    }

    /**
     * Create a new FramedOptionGroup.
     *
     * @param   name    The name of the group.
     * @param   options The Options to edit.
     */
    public FramedOptionGroup (String name, OptionSet options)
    {
        super (name, options);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "FramedOptionGroup(String,OptionSet)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "name: " + name);
        }
        if (logger.level >= Log.WRN) {
            logger.log(Log.WRN, "FramedOptionGroup(String,OptionSet)",
                       "Warning: Framed OptionGroups have been\n " +
                       "deprecated as of version 0.98.0. " +
                       "Please replace the group named '" + name +
                       "' with a plain group with its frame property set " +
                       "to true.");
        }
    }

    // }}}

    // {{{ makeGrid

    /**
     * Create the Grid for the group members.
     */
    protected void makeGrid()
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "makeGrid()", "");
        }

        // this is a hack: since the FramedOptionGroup has been deprecated and
        // superseded by a PlainOptionGroup with a frame property set, but is
        // still kept around to ease transition, the simplest thing to do is
        // to enforce the frame property in the options
        Properties props = new Properties ();
        props.put("option.group." + name + ".frame", "true");
        Option.getResources().addResources(props);
        super.makeGrid();
    }

    // }}}
}
