// {{{ copyright

/********************************************************************
 *
 * $Id: OptionValidator.java,v 1.3 2000/06/06 16:41:27 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.option;

import java.awt.Component;

/**
 * The range of legal values for an {@link Option Option} can be restricted by
 * adding an OptionValidator with {@link Option#addValidator
 * Option.addValidator}. When the Option checks a possible new value in
 * {@link Option#checkValue Option.checkValue} it will also query all
 * registered OptionValidators.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.3 $
 */
public interface OptionValidator
{
    /**
     * Check whether a value is acceptable for an Option. If it is not, the
     * reason should be explained in a message dialog unless component is
     * null.
     *
     * @param   component The Component in which the Option is being edited.
     * @param   option  The option that should be changed.
     * @param   value   The value which is about to be set.
     *
     * @return  True if OK.
     */
    public boolean checkValue(Component component, Option option,
                              Object value);
}
