// {{{ copyright

/********************************************************************
 *
 * $Id: CollateComparator.jpp,v 1.7 2000/06/06 17:00:04 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.util;


import java.util.Comparator;


import java.text.Collator;

/**
 * Standard comparison interface for Strings using a Collator for the
 * current default locale.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.7 $
 */
public class CollateComparator implements Comparator
{
    /**
     * The Collator to use for comparisons.
     */
    private Collator coll = Collator.getInstance();

    // {{{ CollateComparator

    /**
     * Create a new CollateComparator using the default Collator for
     * the current Locale.
     */
    public CollateComparator ()
    {
    }

    /**
     * Create a new CollateComparator.
     *
     * @param   coll    The Collator to use for comparisons.
     */
    public CollateComparator (Collator coll)
    {
        this.coll = coll;
    }

    // }}}

    // {{{ compare

    /**
     * Compare two Objects, using their String representation.
     *
     * @param A The first object.
     * @param B The second object.
     *
     * @return -1 if A&lt;B, 0 if A==B and 1 if A&gt;B.
     */
    public int compare (Object A, Object B)
    {
        return coll.compare (A.toString(), B.toString());
    }

    // }}}
}
