// {{{ copyright

/********************************************************************
 *
 * $Id: CountEvent.java,v 1.2 2000/06/06 16:41:29 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 2000 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.util;

// {{{ imports

import java.util.EventObject;

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * Event object that contains details about read count changes in a {@link
 * CountingInputStream CountingInputStream}.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.2 $
 * @since       0.96.0
 */
public class CountEvent
    extends EventObject
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (CountEvent.class);

    /**
     * The current read count for the event.
     */
    private long count;

    // }}}

    // {{{ constructor

    /**
     * Create a new CountEvent.
     *
     * @param   source  The source of the event, typically the {@link
     *          CountingInputStream CountingInputStream}.
     * @param   count   The new count for the stream.
     */
    public CountEvent (Object source, long count)
    {
        super(source);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "EventObject(Object,long)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "source: " + source + ", " +
                       "count: " + count);
        }
        this.count = count;
    }

    // }}}

    // {{{ getCount

    /**
     * Get the count of the CountEvent.
     *
     * @return  The count of the CountEvent.
     */
    public final long getCount()
    {
        return count;
    }

    // }}}
    // {{{ setCount

    /**
     * Set the count of the CountEvent.
     *
     * @param   count   The count to set.
     */
    public final void setCount(long count)
    {
        this.count = count;
    }

    // }}}

    // {{{ toString

    /**
     * Get a String representation for the event.
     *
     * @return  The String representation for the event.
     */
    public String toString()
    {
        return super.toString() + "[count=" + count + "]";
    }

    // }}}
}
