// {{{ copyright

/********************************************************************
 *
 * $Id: MalformedArgumentListException.java,v 1.6 2000/07/04 13:40:01 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.util;

/**
 * A MalformedArgumentListException is the base class for exceptions thrown by
 * {@link ArgsParser#parse ArgsParser.parse} when it encounters
 * inconsistencies in the command line arguments.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */
public class MalformedArgumentListException extends Exception
{
    // {{{ variables

    /**
     * The name of the option that caused the error.
     */
    private String option;

    // }}}

    // {{{ constructor

    /**
     * Create a new MalformedArgumentListException.
     *
     * @param   message A message explaining the reason for the exception.
     * @param   option  The option that caused the exception.
     */
    public MalformedArgumentListException (String message, String option)
    {
        super(message);
        this.option = option;
    }

    // }}}

    // {{{ getOption

    /**
     * Get the name of the option that caused the error.
     *
     * @return  The option that caused the error, without the leading '-'.
     */
    public String getOption()
    {
        return option;
    }

    // }}}
}
